@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Yancy;
-our $VERSION = '1.041';
+our $VERSION = '1.042';
 # ABSTRACT: Embed a simple admin CMS into your Mojolicious application
 
 #pod =head1 SYNOPSIS
@@ -817,7 +817,7 @@ sub _helper_set {
         $c->app->log->error(
             sprintf 'Error validating item with ID "%s" in schema "%s": %s',
             $id, $schema,
-            join ', ', map { sprintf '%s (%s)', $_->{message}, $_->{path} // '/' } @errors
+            join ', ', @errors
         );
         die \@errors;
     }
@@ -845,7 +845,7 @@ sub _helper_create {
         $c->app->log->error(
             sprintf 'Error validating new item in schema "%s": %s',
             $schema,
-            join ', ', map { sprintf '%s (%s)', $_->{message}, $_->{path} // '/' } @errors
+            join ', ', @errors
         );
         die \@errors;
     }
@@ -980,7 +980,7 @@ Mojolicious::Plugin::Yancy - Embed a simple admin CMS into your Mojolicious appl
 
 =head1 VERSION
 
-version 1.041
+version 1.042
 
 =head1 SYNOPSIS
 
