@@ -1,5 +1,5 @@
 package Yancy::Plugin::Auth::Github;
-our $VERSION = '1.041';
+our $VERSION = '1.042';
 # ABSTRACT: Authenticate using Github's OAuth2 provider
 
 #pod =head1 SYNOPSIS
@@ -21,6 +21,14 @@ our $VERSION = '1.041';
 #pod
 #pod This module allows authenticating using the Github OAuth2 API.
 #pod
+#pod This module extends the L<Yancy::Auth::Plugin::OAuth2> module to add
+#pod Github features.
+#pod
+#pod This module composes the L<Yancy::Auth::Plugin::Role::RequireUser> role
+#pod to provide the
+#pod L<require_user|Yancy::Auth::Plugin::Role::RequireUser/require_user>
+#pod authorization method.
+#pod
 #pod =head1 CONFIGURATION
 #pod
 #pod This plugin has the following configuration options.
@@ -47,6 +55,23 @@ our $VERSION = '1.041';
 #pod     # Expire a session after 1 day of inactivity
 #pod     app->sessions->default_expiration( 24 * 60 * 60 );
 #pod
+#pod =head1 HELPERS
+#pod
+#pod This plugin has the following helpers.
+#pod
+#pod =head2 yancy.auth.current_user
+#pod
+#pod Get the current user from the session, if any. Returns C<undef> if no
+#pod user was found in the session.
+#pod
+#pod     my $user = $c->yancy->auth->current_user
+#pod         || return $c->render( status => 401, text => 'Unauthorized' );
+#pod
+#pod =head2 yancy.auth.require_user
+#pod
+#pod Validate there is a logged-in user and optionally that the user data has
+#pod certain values. See L<Yancy::Plugin::Auth::Role::RequireUser/require_user>.
+#pod
 #pod =head1 TEMPLATES
 #pod
 #pod =head2 layouts/yancy/auth.html.ep
@@ -120,50 +145,6 @@ sub _get_user {
     return $c->yancy->backend->get( $schema_name, $username );
 }
 
-#pod =method require_user
-#pod
-#pod     my $subref = $c->yancy->auth->require_user( \%match );
-#pod
-#pod Build a callback to validate there is a logged-in user, and optionally
-#pod that the current user has certain fields set. C<\%match> is optional and
-#pod is a L<SQL::Abstract where clause|SQL::Abstract/WHERE CLAUSES> matched
-#pod with L<Yancy::Util/match>.
-#pod
-#pod     # Ensure the user is logged-in
-#pod     my $user_cb = $app->yancy->auth->require_user;
-#pod     my $user_only = $app->routes->under( $user_cb );
-#pod
-#pod     # Ensure the user's "is_admin" field is set to 1
-#pod     my $admin_cb = $app->yancy->auth->require_user( { is_admin => 1 } );
-#pod     my $admin_only = $app->routes->under( $admin_cb );
-#pod
-#pod =cut
-
-sub require_user {
-    my ( $self, $c, $where ) = @_;
-    return sub {
-        my ( $c ) = @_;
-        #; say "Are you authorized? " . $c->yancy->auth->current_user;
-        my $user = $c->yancy->auth->current_user;
-        if ( !$where && $user ) {
-            return 1;
-        }
-        if ( $where && match( $where, $user ) ) {
-            return 1;
-        }
-        $c->stash(
-            template => 'yancy/auth/unauthorized',
-            status => 401,
-            login_route => $self->route->render,
-        );
-        $c->respond_to(
-            json => {},
-            html => {},
-        );
-        return undef;
-    };
-}
-
 sub _handle_auth {
     my ( $self, $c ) = @_;
 
@@ -233,7 +214,7 @@ Yancy::Plugin::Auth::Github - Authenticate using Github's OAuth2 provider
 
 =head1 VERSION
 
-version 1.041
+version 1.042
 
 =head1 SYNOPSIS
 
@@ -254,29 +235,20 @@ version 1.041
 
 This module allows authenticating using the Github OAuth2 API.
 
+This module extends the L<Yancy::Auth::Plugin::OAuth2> module to add
+Github features.
+
+This module composes the L<Yancy::Auth::Plugin::Role::RequireUser> role
+to provide the
+L<require_user|Yancy::Auth::Plugin::Role::RequireUser/require_user>
+authorization method.
+
 =head1 METHODS
 
 =head2 current_user
 
 Returns the user row of the currently-logged-in user.
 
-=head2 require_user
-
-    my $subref = $c->yancy->auth->require_user( \%match );
-
-Build a callback to validate there is a logged-in user, and optionally
-that the current user has certain fields set. C<\%match> is optional and
-is a L<SQL::Abstract where clause|SQL::Abstract/WHERE CLAUSES> matched
-with L<Yancy::Util/match>.
-
-    # Ensure the user is logged-in
-    my $user_cb = $app->yancy->auth->require_user;
-    my $user_only = $app->routes->under( $user_cb );
-
-    # Ensure the user's "is_admin" field is set to 1
-    my $admin_cb = $app->yancy->auth->require_user( { is_admin => 1 } );
-    my $admin_only = $app->routes->under( $admin_cb );
-
 =head1 CONFIGURATION
 
 This plugin has the following configuration options.
@@ -303,6 +275,23 @@ default_expiration|https://mojolicious.org/perldoc/Mojolicious/Sessions#default_
     # Expire a session after 1 day of inactivity
     app->sessions->default_expiration( 24 * 60 * 60 );
 
+=head1 HELPERS
+
+This plugin has the following helpers.
+
+=head2 yancy.auth.current_user
+
+Get the current user from the session, if any. Returns C<undef> if no
+user was found in the session.
+
+    my $user = $c->yancy->auth->current_user
+        || return $c->render( status => 401, text => 'Unauthorized' );
+
+=head2 yancy.auth.require_user
+
+Validate there is a logged-in user and optionally that the user data has
+certain values. See L<Yancy::Plugin::Auth::Role::RequireUser/require_user>.
+
 =head1 TEMPLATES
 
 =head2 layouts/yancy/auth.html.ep
